@@ -11,8 +11,9 @@ def get_articles():
 	g.go("http://www.maketecheasier.com")
 	
 	css_path = ".post .entry-header .entry-title a"
+	summary_path = ".post .entry-content p"
 	
 	posts = parser.get_articles(g, css_path, css_path,
-		"maketecheasier", "www.maketecheasier.com")
+		"maketecheasier", "www.maketecheasier.com", summary_path)
 	
 	return posts
