@@ -11,13 +11,15 @@ def get_articles(reddits=['tech']):
 	css_path = 'div.entry p.title a.title'
 	
 	articles = []
+	links = []
 	
 	for r in reddits:
 		g.go('http://www.reddit.com/r/%s' %r)
 		
 		for article in parser.get_articles(g, css_path, css_path,
 			'reddit', 'www.reddit.com'):
-			if article not in articles:
+			if article['link'] not in links:
+				links.append(article['link'])
 				articles.append(article)
 	
 	return articles
